/*
 *  raismth - Rai Smooth Streaming Player for linux
 *  Copyright (C) 2012 Riccardo Cioncolini | mitm@hotmail.it
 *  
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *  
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *  
 *  @author: mitm(@hotmail.it) Riccardo Cioncolini
 *  @url: http://acab.servebeer.com
 */

// The only global object for this extension.
var raismth = 
{
	eventHandlers: {
		"load": "initialize",
		"unload": "shutdown",
	},
	handleEvent: function(e) {
		dump('[RAISMTH] Event handler: ' + e.type + '\n');
		if (e.type in this.eventHandlers)
		  	this[this.eventHandlers[e.type]](e);
	},
};

// Basic namespace implementation.
(function() {

var namespaces = [];

// Namespace registration
this.ns = function(fn) {
	var ns = {};
    	namespaces.push(fn, ns);
    	return ns;
};

// Namespace initialization
this.initialize = function() {
    	for (var i=0; i<namespaces.length; i+=2) {
		var fn = namespaces[i];
		var ns = namespaces[i+1];
		fn.apply(ns);
    	}
	window.document.addEventListener("DOMContentLoaded", raismth.preload, true);
	window.document.addEventListener("load", raismth.loaded, true);
	window.document.addEventListener("unload", raismth.unloaded, true);
};

this.preload = function(event){
	this.doc = event.originalTarget;

	if(raismth.utils.IsRaiPage(this.doc)) {	
	        raismth.container = gBrowser.tabContainer;
		raismth.container.addEventListener("TabSelect", raismth.utils.tabselect, false);
		raismth.container.addEventListener("TabClose",  raismth.utils.tabMonitor, false, false);

		raismth.doc = this.doc;
		if(raismth.utils.set_os()) {
			let version = '2.0.30226.2';
			raismth.utils.kill_refresh(this.doc);
	                if(!raismth.silverlight.isInstalled(version, this.doc)) { 
				dump('[RAISMTH] native framework not detected/supported, spoofing needed\n');
				raismth.silverlight.spoof(this.doc);
			} else {
				dump('[RAISMTH] native framework detected\n');
				raismth.nativePlayer = true;
			}

			if(raismth.utils.load_prefs()){
			} else {
			}
		} else {
			alert('Raismth: Operative system not supported [FATAL]');
		}
	}
};
this.loaded = function(event) {
	this.doc = event.originalTarget;
	// dump(this.doc.location.href + '\n');
	if(raismth.utils.IsRaiPage(this.doc)) {
		// dump('RAI page ' + this.doc.location.href + '\n');
                raismth.rai.injectRai(this.doc);
		let container = raismth.rai.injectSilverlightPlayer(this.doc);
                raismth.rai.injectSilverlightControl(this.doc, container);
		raismth.rai.injectRaismthStatus(this.doc, container);
	}
};
this.unloaded = function(event) {
        this.doc = event.originalTarget;
	if(raismth.utils.IsRaiPage(this.doc)) {
		let ts = null;
		let indice = null;
		let pid = null;
		if(this.doc.getElementById('raismthWindow')) {
			ts = this.doc.getElementById('raismthWindow').getAttribute('name');
			indice = raismth.utils.arrayIndexOf(raismth.rai_windows_ts, parseInt(ts));
			pid = raismth.player_istances_pid[indice];
			raismth.utils.clean_temp_files(pid);
			if (raismth.player_istances[indice] && raismth.player_istances[indice].isRunning) raismth.player_istances[indice].kill();
		}
		dump('[RAISMTH] doc unload: ' + this.doc.location.href + '\n');
		dump('[RAISMTH] RAI page ' + ts + '\n');
		raismth.utils.purge_arrays(this.doc);
	}
};
// Clean up
this.shutdown = function() {
	dump('[RAISMTH] Listeners off\n');
	raismth.container.removeEventListener("TabSelect", raismth.utils.tabselect, false);
	raismth.container.removeEventListener("TabSelect", raismth.utils.tabMonitor, false, false);
	window.document.removeEventListener("DOMContentLoaded", raismth.preload, true);
	window.document.removeEventListener("load", raismth.loaded, true);
	window.removeEventListener("load", raismth, false);
	window.removeEventListener("unload", raismth, false);
};

// Register handlers to maintain extension life cycle.
dump('[RAISMTH] Listeners on\n');
window.addEventListener("load", raismth, false);
window.addEventListener("unload", raismth, false);

}).apply(raismth);
